@@ -107,7 +107,7 @@ class Processor:
             self.semibin_model = args.semibin_model
             self.skip_binners = [binner.lower() for binner in args.skip_binners]
             self.check_binners_to_skip()
-            if "get_bam_indices" not in self.workflows:
+            if "get_bam_indices" not in self.workflows and "complete_assembly" not in self.workflows:
                 self.workflows.insert(0, 'get_bam_indices')
         except AttributeError:
             self.min_contig_size = 1500
@@ -177,9 +177,14 @@ class Processor:
             self.mag_directory = 'none'
 
         try:
-            self.gtdbtk = args.gtdb_path
-            self.eggnog = args.eggnog_db_path
-            # self.enrichm = args.enrichm_db_path
+            if args.gtdb_path is not None:
+                self.gtdbtk = args.gtdb_path
+            else:
+                self.gtdbtk = Config.get_software_db_path('GTDBTK_DATA_PATH', '--gtdb-path')
+            if args.eggnog_db_path is not None:
+                self.eggnog = args.eggnog_db_path
+            else:
+                self.eggnog = Config.get_software_db_path('EGGNOG_DATA_DIR', '--eggnog-db-path')
         except AttributeError:
             self.gtdbtk = Config.get_software_db_path('GTDBTK_DATA_PATH', '--gtdb-path')
             self.eggnog = Config.get_software_db_path('EGGNOG_DATA_DIR', '--eggnog-db-path')
@@ -195,25 +200,45 @@ class Processor:
         except AttributeError:
             self.previous_runs = 'none'
 
+        # Aviary cluster arguments
         try:
-            self.min_completeness = args.min_completeness
-            self.max_contamination = args.max_contamination
-            self.ani = args.ani
-            self.precluster_ani = args.precluster_ani
+            if args.min_completeness == 'none':
+                self.min_completeness = ' '
+            else:
+                self.min_completeness = f'--min-completeness {args.min_completeness}'
+
+            if args.max_contamination == 'none':
+                self.max_contamination = ' '
+            else:
+                self.max_contamination = f'--max-contamination {args.max_contamination}'
+
+            self.precluster_ani = fraction_to_percent(args.precluster_ani)
+            self.ani = fraction_to_percent(args.ani)
             self.precluster_method = args.precluster_method
+            self.use_checkm2_scores = args.use_checkm2_scores
+            self.pggb_params = args.pggb_params
         except AttributeError:
             self.min_completeness = 'none'
             self.max_contamination = 'none'
             self.ani = 'none'
             self.precluster_ani = 'none'
             self.precluster_method = 'none'
-
+            self.use_checkm2_scores = False
+            self.pggb_params = 'none'
 
         try:
-            # self.checkm2_db = Config.get_software_db_path('CHECKM2DB', '--checkm2-db-path')
-            self.checkm2_db = os.environ['CHECKM2DB']
-        except KeyError:
-            self.checkm2_db = 'none'
+            if args.checkm2_db_path is not None:
+                self.checkm2_db = args.checkm2_db_path
+            else:
+                self.checkm2_db = Config.get_software_db_path('CHECKM2DB', '--checkm2-db-path')
+        except AttributeError:
+            self.checkm2_db = Config.get_software_db_path('CHECKM2DB', '--checkm2-db-path')
+            # self.checkm2_db = 'none'
+
+        # Must be always be first workflow
+        if args.download:
+            self.workflows.insert(0, 'download_databases')
+
 
     def make_config(self):
         """
@@ -266,7 +291,8 @@ class Processor:
         conf["eggnog_folder"] = self.eggnog
         conf["strain_analysis"] = self.strain_analysis
 
-        conf["checkm2_db_path"] = self.checkm2_db
+        conf["checkm2_db_folder"] = self.checkm2_db
+        conf["use_checkm2_scores"] = self.use_checkm2_scores
         conf["mag_directory"] = self.mag_directory
         conf["mag_extension"] = self.mag_extension
         # conf["mags"] = self.mags
@@ -276,6 +302,7 @@ class Processor:
         conf["ani"] = self.ani
         conf["precluster_ani"] = self.precluster_ani
         conf["precluster_method"] = self.precluster_method
+        conf["pggb_params"] = self.pggb_params
 
         with open(self.config, "w") as f:
             yaml.dump(conf, f)
@@ -377,15 +404,15 @@ class Processor:
         for workflow in self.workflows:
             cmd = (
                 "snakemake --snakefile {snakefile} --directory {working_dir} "
-                "{jobs}--rerun-incomplete "
-                "--configfile '{config_file}' --nolock"
-                " {profile} {conda_frontend} --use-conda {conda_prefix}"
-                " {dryrun}{notemp}{args}"
+                "{jobs} --rerun-incomplete "
+                "--configfile '{config_file}' --nolock "
+                "{profile} {conda_frontend} --use-conda {conda_prefix} "
+                "{dryrun}{notemp}{args}"
                 " {target_rule}"
             ).format(
                 snakefile=get_snakefile(),
                 working_dir=self.output,
-                jobs="--jobs {} ".format(cores) if cores is not None else "",
+                jobs="--jobs {}".format(cores) if cores is not None else "",
                 config_file=self.config,
                 profile="" if (profile is None) else "--profile {}".format(profile),
                 dryrun="--dryrun " if dryrun else "",
@@ -401,4 +428,9 @@ class Processor:
             except subprocess.CalledProcessError as e:
                 # removes the traceback
                 logging.critical(e)
-                exit(1)
\ No newline at end of file
+                exit(1)
+
+def fraction_to_percent(val):
+    if val <= 1:
+        return val * 100
+    return val
\ No newline at end of file
